==> komparator_0.3.orig.tar.bz2: komparator4-0.3/src/komparatortreewidget.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Georg Hennig                                    *
 *   Email: georg.hennig@web.de                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KOMPARATORTREEWIDGET_H_
#define _KOMPARATORTREEWIDGET_H_

#include <QTreeWidget>

class KomparatorTreeWidget : public QTreeWidget
{
	Q_OBJECT

	public:
		KomparatorTreeWidget( QWidget *parent = 0 );
		~KomparatorTreeWidget();

		virtual void startDrag( Qt::DropActions supported_actions );
		virtual void keyPressEvent( QKeyEvent *event );
		virtual void dropEvent( QDropEvent * event );
		QStringList mimeTypes() const;

	signals:
		void signalDropped( QWidget *source, QWidget *destination, const QPoint &pos );
};

#endif

==> komparator_0.6.orig.tar.bz2: komparator4-0.6/src/komparatortreewidget.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Georg Hennig                                    *
 *   Email: georg.hennig@web.de                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _KOMPARATORTREEWIDGET_H_
#define _KOMPARATORTREEWIDGET_H_

#include <QTreeWidget>

class KomparatorTreeWidget : public QTreeWidget
{
	Q_OBJECT

	public:
		KomparatorTreeWidget( QWidget *parent = 0 );
		~KomparatorTreeWidget();

		virtual void startDrag( Qt::DropActions supported_actions );
		virtual void mousePressEvent( QMouseEvent *event );
		virtual void keyPressEvent( QKeyEvent *event );
		virtual void dropEvent( QDropEvent * event );
		QStringList mimeTypes() const;

	signals:
		void signalDropped( QWidget *source, QWidget *destination, const QPoint &pos );

	public slots:
		virtual void slotExecute( QTreeWidgetItem *item, int );

	private:
		bool ctrl_or_shift_down;
};

#endif
